@@ -8,7 +8,7 @@ test_that("1-compartment model", {
   expect_equal(
     t,
     list(k10=0.64, Vss=25, thalf=1.083, alpha=0.64, trueA=0.04, fracA=1,
-         V1=25, CL=16, ka=NULL, tlag=NULL)
+         V1=25, CL=16)
   )
   t_vec <- calc_derived_1cpt(CL=c(16, 8), V=c(25, 25))
   expect_equal(
@@ -21,9 +21,7 @@ test_that("1-compartment model", {
       trueA=c(0.04, 0.04),
       fracA=1,
       V1=c(25, 25),
-      CL=c(16, 8),
-      ka=NULL,
-      tlag=NULL
+      CL=c(16, 8)
     )
   )
 })
@@ -35,7 +33,7 @@ test_that("2-compartment model", {
     list(
       k10=0.64, k12=0.02, k21=0.01, Vss=75, thalf_alpha=1.0497, thalf_beta=71.514, alpha=0.66031, beta=0.0096925,
       trueA=0.039981, trueB=1.8908e-05, fracA=0.99953, fracB=0.0004727,
-      V1=25, V2=50, CL=16, Q2=0.5, ka=NULL, tlag=NULL
+      V1=25, V2=50, CL=16, Q2=0.5
     )
   )
   t_vec <- calc_derived_2cpt(CL=c(16, 8), V1=c(25, 50), V2=c(50, 25), Q=c(0.5, 1))
@@ -57,9 +55,7 @@ test_that("2-compartment model", {
       V1=c(25, 50),
       V2=c(50, 25),
       CL=c(16, 8),
-      Q2=c(0.5, 1),
-      ka=NULL,
-      tlag=NULL
+      Q2=c(0.5, 1)
     )
   )
 })
@@ -74,7 +70,7 @@ test_that("3-compartment model", {
       alpha=17.7, beta=0.59449, gamma=0.0044742,
       trueA=0.038279, trueB=0.0043467, trueC=0.0001098,
       fracA=0.89572, fracB=0.10171, fracC=0.0025692,
-      V1=23.4, V2=114, V3=4614, CL=29.4, Q2=270, Q3=73, ka=NULL, tlag=NULL
+      V1=23.4, V2=114, V3=4614, CL=29.4, Q2=270, Q3=73
     )
   )
   t_vec <-
@@ -115,9 +111,7 @@ test_that("3-compartment model", {
       V3=c(40, 100),
       CL=c(20, 10),
       Q2=c(10, 20),
-      Q3=c(30, 40),
-      ka=NULL,
-      tlag=NULL
+      Q3=c(30, 40)
     )
   )
 })
